Package 'tidyklips'

Title: Load Korea Labor & Income Panel Study (KLIPS) Data as Data Frames
Description: Loading the Korea Labor Institute's KLIPS (Korea Labor & Income Panel Study) panel data and returning data frames. Users must download 26 years of panel data from the Korea Labor Institute website and save it in a folder in an appropriate path. Afterwards, users can easily convert the data into a data frame using this package.
Authors: Cheon Geun Choi [aut, cre]
Maintainer: Cheon Geun Choi <[email protected]>
License: MIT + file LICENSE
Version: 0.3.0
Built: 2026-05-20 07:11:13 UTC
Source: https://github.com/cran/tidyklips

Help Index


‘getaklips()’ is used to obtain data.frame for KLIPS (additional survey)

Description

‘getaklips()’ is used to obtain data.frame for KLIPS (additional survey)

Usage

getaklips(
  path,
  year,
  datatype = c("stata", "spss", "sas", "xlsx"),
  klipsvars = c("6101", "6102"),
  outvars = c("activity", "howmayactivity")
)

Arguments

path

A string vector specifying folder containing KLIPS additional survey data

year

an integer vector specifying the years from 1998 to 2023 that the user wants to include in the dataframe.

datatype

A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel")

klipsvars

A string vector specifying the variables in the raw data that you want to convert to a data frame ("6101", "6102")

outvars

A string vector specifying the variable names of converted data ("acivity", "howmayactivity")

Value

A data frame containing klips household member data with the specified years and variables.

  • getaklips() returns an integer dataframe with two and more columns and rows for each respondent. The first column, pid, refers to the respondent id number, and the last column, year, refers to the year that the user wants to include in the dataframe.

Examples

path <- system.file("extdata", package = "tidyklips")
df <- getaklips(path = path, year = 2023, datatype = "stata")
df %>%
  dplyr::group_by(year, activity) %>%
  dplyr::summarise(count = dplyr::n()) %>%
  dplyr::mutate(proportion = count / sum(count))

‘gethklips()’ is used to obtain data.frame for KLIPS (head of household survey)

Description

‘gethklips()’ is used to obtain data.frame for KLIPS (head of household survey)

Usage

gethklips(
  path,
  year,
  datatype = c("stata", "spss", "sas", "xlsx"),
  klipsvars = c("0141", "2102"),
  outvars = c("province", "income")
)

Arguments

path

A string vector specifying folder containing KLIPS head of household survey data

year

an integer vector specifying the years from 1998 to 2023 that the user wants to include in the dataframe.

datatype

A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel")

klipsvars

A string vector specifying the variables in the raw data that you want to convert to a data frame ("0141", "2102")

outvars

A string vector specifying the variable names of converted data ("province", "income")

Value

A data frame containing klips household member data with the specified years and variables.

  • gethklips() returns an integer dataframe with two and more columns and rows for each head of household. The first column, hhid, refers to the respondent id number, and the last column, year, refers to the year that the user wants to include in the dataframe.

Examples

path <- system.file("extdata", package = "tidyklips")
df <- gethklips(path = path, year = 2023, datatype = "stata")
df %>%
  dplyr::group_by(year) %>%
  dplyr::summarise(count = dplyr::n()) %>%
  dplyr::mutate(proportion = count / sum(count))

‘getpklips()’ is used to obtain data.frame for KLIPS (household member survey)

Description

‘getpklips()’ is used to obtain data.frame for KLIPS (household member survey)

Usage

getpklips(
  path,
  year,
  datatype = c("stata", "spss", "sas", "xlsx"),
  klipsvars = c("0101", "0107"),
  outvars = c("gender", "age")
)

Arguments

path

A string vector specifying folder containing KLIPS household member survey data

year

an integer vector specifying the years from 1998 to 2023 that the user wants to include in the dataframe.

datatype

A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel")

klipsvars

A string vector specifying the variables in the raw data that you want to convert to a data frame ("0101", "0107")

outvars

A string vector specifying the variable names of converted data ("gender", "age")

Value

A data frame containing klips household member data with the specified years and variables.

  • getpklips() returns an integer dataframe with two and more columns and rows for each respondent. The first column, pid, refers to the respondent id number, and the last column, year, refers to the year that the user wants to include in the dataframe.

Examples

path <- system.file("extdata", package = "tidyklips")
df <- getpklips(path = path, year = 1998, datatype = "stata")
df %>%
  dplyr::group_by(year, gender) %>%
  dplyr::summarise(count = dplyr::n()) %>%
  dplyr::mutate(proportion = count / sum(count))

‘getwklips()’ is used to obtain data.frame for KLIPS (career data)

Description

‘getwklips()’ is used to obtain data.frame for KLIPS (career data)

Usage

getwklips(
  path,
  datatype = c("stata", "spss", "sas", "xlsx"),
  klipsvars = c("jobseq", "jobtype"),
  outvars = c("jobseq", "jobtype")
)

Arguments

path

A string vector specifying folder containing KLIPS career data

datatype

A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel")

klipsvars

A string vector specifying the variables in the raw data that you want to convert to a data frame ("jobseq", "jobtype")

outvars

A string vector specifying the variable names of converted data ("jobseq", "jobtype")

Value

A data frame containing klips household member data with the specified years and variables.

  • getwklips() returns an integer dataframe with two and more columns and rows for each respondent. The first column, pid, refers to the respondent id number, and the last column, year, refers to the year that the user wants to include in the dataframe.

Examples

path <- system.file("extdata", package = "tidyklips")
df <- getwklips(path = path, datatype = "stata")
df %>%
  dplyr::group_by(jobseq) %>%
  dplyr::summarise(count = dplyr::n()) %>%
  dplyr::mutate(proportion = count / sum(count))

2023 yr Klips house member survey dataframe

Description

Look up 23364 house member survey response data.

Usage

klips26p

Format

Data frame with columns

pid

response id.

gender

gender.

age

age.

https://www.kli.re.kr/klips

Examples

klips26p