| Title: | Load Korea Labor & Income Panel Study (KLIPS) Data as Data Frames |
|---|---|
| Description: | Loading the Korea Labor Institute's KLIPS (Korea Labor & Income Panel Study) panel data and returning data frames. Users must download 26 years of panel data from the Korea Labor Institute website and save it in a folder in an appropriate path. Afterwards, users can easily convert the data into a data frame using this package. |
| Authors: | Cheon Geun Choi [aut, cre] |
| Maintainer: | Cheon Geun Choi <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.0 |
| Built: | 2026-05-20 07:11:13 UTC |
| Source: | https://github.com/cran/tidyklips |
‘getaklips()’ is used to obtain data.frame for KLIPS (additional survey)
getaklips( path, year, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("6101", "6102"), outvars = c("activity", "howmayactivity") )getaklips( path, year, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("6101", "6102"), outvars = c("activity", "howmayactivity") )
path |
A string vector specifying folder containing KLIPS additional survey data |
year |
an integer vector specifying the years from 1998 to 2023 that the user wants to include in the dataframe. |
datatype |
A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel") |
klipsvars |
A string vector specifying the variables in the raw data that you want to convert to a data frame ("6101", "6102") |
outvars |
A string vector specifying the variable names of converted data ("acivity", "howmayactivity") |
A data frame containing klips household member data with the specified years and variables.
getaklips() returns an integer dataframe with two and more columns and
rows for each respondent. The first column, pid,
refers to the respondent id number, and the last column, year,
refers to the year that the user wants to include in the dataframe.
path <- system.file("extdata", package = "tidyklips") df <- getaklips(path = path, year = 2023, datatype = "stata") df %>% dplyr::group_by(year, activity) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))path <- system.file("extdata", package = "tidyklips") df <- getaklips(path = path, year = 2023, datatype = "stata") df %>% dplyr::group_by(year, activity) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))
‘gethklips()’ is used to obtain data.frame for KLIPS (head of household survey)
gethklips( path, year, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("0141", "2102"), outvars = c("province", "income") )gethklips( path, year, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("0141", "2102"), outvars = c("province", "income") )
path |
A string vector specifying folder containing KLIPS head of household survey data |
year |
an integer vector specifying the years from 1998 to 2023 that the user wants to include in the dataframe. |
datatype |
A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel") |
klipsvars |
A string vector specifying the variables in the raw data that you want to convert to a data frame ("0141", "2102") |
outvars |
A string vector specifying the variable names of converted data ("province", "income") |
A data frame containing klips household member data with the specified years and variables.
gethklips() returns an integer dataframe with two and more columns and
rows for each head of household. The first column, hhid,
refers to the respondent id number, and the last column, year,
refers to the year that the user wants to include in the dataframe.
path <- system.file("extdata", package = "tidyklips") df <- gethklips(path = path, year = 2023, datatype = "stata") df %>% dplyr::group_by(year) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))path <- system.file("extdata", package = "tidyklips") df <- gethklips(path = path, year = 2023, datatype = "stata") df %>% dplyr::group_by(year) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))
‘getpklips()’ is used to obtain data.frame for KLIPS (household member survey)
getpklips( path, year, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("0101", "0107"), outvars = c("gender", "age") )getpklips( path, year, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("0101", "0107"), outvars = c("gender", "age") )
path |
A string vector specifying folder containing KLIPS household member survey data |
year |
an integer vector specifying the years from 1998 to 2023 that the user wants to include in the dataframe. |
datatype |
A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel") |
klipsvars |
A string vector specifying the variables in the raw data that you want to convert to a data frame ("0101", "0107") |
outvars |
A string vector specifying the variable names of converted data ("gender", "age") |
A data frame containing klips household member data with the specified years and variables.
getpklips() returns an integer dataframe with two and more columns and
rows for each respondent. The first column, pid,
refers to the respondent id number, and the last column, year,
refers to the year that the user wants to include in the dataframe.
path <- system.file("extdata", package = "tidyklips") df <- getpklips(path = path, year = 1998, datatype = "stata") df %>% dplyr::group_by(year, gender) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))path <- system.file("extdata", package = "tidyklips") df <- getpklips(path = path, year = 1998, datatype = "stata") df %>% dplyr::group_by(year, gender) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))
‘getwklips()’ is used to obtain data.frame for KLIPS (career data)
getwklips( path, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("jobseq", "jobtype"), outvars = c("jobseq", "jobtype") )getwklips( path, datatype = c("stata", "spss", "sas", "xlsx"), klipsvars = c("jobseq", "jobtype"), outvars = c("jobseq", "jobtype") )
path |
A string vector specifying folder containing KLIPS career data |
datatype |
A string vector specifying the format of the raw data you want to convert to a data frame ("spss", "sas", "stata", "excel") |
klipsvars |
A string vector specifying the variables in the raw data that you want to convert to a data frame ("jobseq", "jobtype") |
outvars |
A string vector specifying the variable names of converted data ("jobseq", "jobtype") |
A data frame containing klips household member data with the specified years and variables.
getwklips() returns an integer dataframe with two and more columns and
rows for each respondent. The first column, pid,
refers to the respondent id number, and the last column, year,
refers to the year that the user wants to include in the dataframe.
path <- system.file("extdata", package = "tidyklips") df <- getwklips(path = path, datatype = "stata") df %>% dplyr::group_by(jobseq) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))path <- system.file("extdata", package = "tidyklips") df <- getwklips(path = path, datatype = "stata") df %>% dplyr::group_by(jobseq) %>% dplyr::summarise(count = dplyr::n()) %>% dplyr::mutate(proportion = count / sum(count))
Look up 23364 house member survey response data.
klips26pklips26p
Data frame with columns
response id.
gender.
age.
klips26pklips26p